==> PrestaShop_ORLENPaczka_v1.0.4.zip: orlenpaczka/CHANGELOG.md <==
# ChangeLog

## 1.0.4 (2025-12-10)
  - **Poprawki:**
    - [DV-8955] Poprawka ładowania skryptów na froncie tylko na stronie zamówienia oraz zmiana lazy loading mapy

## 1.0.3 (2025-11-06)
  - **Nowe funkcjonalności:**
    - [DV-8730] Zmiana overridów w celu zapewnienia kompatybilności z inpost
    - [DV-8522] Usunięcie walidacji dla nowego typu przesyłki w formularzu ShipmentType
    - [DV-6979] Ukrywanie hasła gwiazdkami w formularzu autoryzacji (BG #65, #73, #74)
    - [DV-6979] Naprawa filtrowania gridów
  - **Poprawki:**
    - [DV-8814] Poprawka zwracania typu w Voterze plus zmiana triggera mapy
    - [DV-8526] Poprawka nazwy zakładki w skrypcie upgrade
    - [DV-8523] Naprawa globalnej zmiennej token w DisplayBackOfficeHeader
    - [DV-6979] Poprawka paddingu w szablonie carrier extra content dla lepszego odstępu
    - [DV-6979] Poprawki tłumaczeń w plikach językowych (ModulesOrlenpaczkaForm, ModulesOrlenpaczkaOrder, ModulesOrlenpaczkaShop)
    - [DV-6979] Naprawa tworzenia przesyłek (PackageCreator) i dodawania przewoźnika podczas instalacji
    - [DV-6979] Poprawka w kontrolerze ShipmentController
    - [DV-6979] Usunięcie nieużywanych serwisów z głównego pliku modułu
  - **Zmiany techniczne:**
    - Dodanie skryptu upgrade-1.0.3.php (dezaktywacja zakładki AdminOrlenPaczka)
    - Refaktoryzacja walidacji w formularzach i kontrolerach
    - Aktualizacja logiki JavaScript w carrier.js

## 1.0.2 (2025-10-23)
  - **Nowe funkcjonalności:**
    - [DV-6979] Dodanie możliwości ponownej instalacji komponentów (carrier, hooks, database) z poziomu konfiguracji modułu (BG #64, #66, #67, #68, #69, #72)
  - **Poprawki bazy danych:**
    - Zmiana kolumny `id_pickup` na nullable w tabeli `orlenpaczka_package`
  - **Poprawki hooków:**
    - Odrejestrowanie starych hooków: `displayAdminOrderTop`, `displayAdminOrder`
    - Rejestracja nowego hooka: `displayAdminOrderMainBottom`
    - Zmiana nazwy klasy hooka z `DisplayAdminOrder` na `DisplayAdminOrderMainBottom`
  - **Poprawki funkcjonalności:**
    - Dodanie helpera `CarrierHelper` do sprawdzania przewoźników
    - Rozszerzenie prezentacji zamówień w panelu administracyjnym (`AdminOrderPresenter`, `OrderView`)
    - Poprawki w tworzeniu paczek (`PackageCreator`)
    - Ulepszenia w instalatorze przewoźników (`CarrierInstaller`)
  - **Poprawki UI/UX:**
    - Poprawki w szablonie widoku zamówienia (`orlen_order.html.twig`)
    - Dodanie stylów CSS dla lepszego wyświetlania
    - Poprawki w JavaScript dla formularzy i przewoźników (admin/carrier.js, admin/form.js)
  - **Tłumaczenia:**
    - Dodanie nowych tłumaczeń w plikach: ModulesOrlenpaczkaForm.pl-PL.xlf, ModulesOrlenpaczkaOrder.pl-PL.xlf, ModulesOrlenpaczkaTab.pl-PL.xlf

## 1.0.1 (2025-10-17)
  - **Nowe funkcjonalności:**
    - [DV-6979] Naprawa routingu dla PrestaShop
    - [DV-6979] Wyrzucenie niepotrzebnego installera
  - **Poprawki Bugherd:**
    - Usunięcie walidacji zamówienia kuriera przed wysyłką maili
    - Usunięcie opisu
    - Rozdzielenie danych do etykiety
    - Poprawki tłumaczeń i ustawienie domyślnego typu etykiety
    - Poprawki protokołów i logów
  - **Poprawki dla PrestaShop 8:**
    - Naprawa przełączania na PrestaShop 8
  - **Inne:**
    - Poprawki dostosowania dla PrestaShop 9
    - Różne poprawki związane z Bugherd

==> PrestaShop_ORLENPaczka_v1.0.5.zip: orlenpaczka/CHANGELOG.md <==
# ChangeLog

## 1.0.5 (2026-01-16)
  - **Poprawki:**
    - [DD-9301] Poprawa namespace w override'zie Order dla zapewnienia kompatybilności
    - [DD-9301] Dodanie zabezpieczenia dla błędu PrestaShop związanego z czyszczeniem cache Doctrine proxy podczas upgrade modułu
    - [DV-9437] Poprawka w AuthorizationController - zmiana type hint metody updateSandboxAction z konkretnej klasy na interface (CredentialsProviderInterface)
    - [DV-8814] Poprawka return w voter oraz zmiana triggera mapy na lazy loading

## 1.0.4 (2025-12-10)
  - **Poprawki:**
    - [DV-8955] Poprawka ładowania skryptów na froncie tylko na stronie zamówienia oraz zmiana lazy loading mapy

## 1.0.3 (2025-11-06)
  - **Nowe funkcjonalności:**
    - [DV-8730] Zmiana overridów w celu zapewnienia kompatybilności z inpost
    - [DV-8522] Usunięcie walidacji dla nowego typu przesyłki w formularzu ShipmentType
    - [DV-6979] Ukrywanie hasła gwiazdkami w formularzu autoryzacji (BG #65, #73, #74)
    - [DV-6979] Naprawa filtrowania gridów
  - **Poprawki:**
    - [DV-8814] Poprawka zwracania typu w Voterze plus zmiana triggera mapy
    - [DV-8526] Poprawka nazwy zakładki w skrypcie upgrade
    - [DV-8523] Naprawa globalnej zmiennej token w DisplayBackOfficeHeader
    - [DV-6979] Poprawka paddingu w szablonie carrier extra content dla lepszego odstępu
    - [DV-6979] Poprawki tłumaczeń w plikach językowych (ModulesOrlenpaczkaForm, ModulesOrlenpaczkaOrder, ModulesOrlenpaczkaShop)
    - [DV-6979] Naprawa tworzenia przesyłek (PackageCreator) i dodawania przewoźnika podczas instalacji
    - [DV-6979] Poprawka w kontrolerze ShipmentController
    - [DV-6979] Usunięcie nieużywanych serwisów z głównego pliku modułu
  - **Zmiany techniczne:**
    - Dodanie skryptu upgrade-1.0.3.php (dezaktywacja zakładki AdminOrlenPaczka)
    - Refaktoryzacja walidacji w formularzach i kontrolerach
    - Aktualizacja logiki JavaScript w carrier.js

## 1.0.2 (2025-10-23)
  - **Nowe funkcjonalności:**
    - [DV-6979] Dodanie możliwości ponownej instalacji komponentów (carrier, hooks, database) z poziomu konfiguracji modułu (BG #64, #66, #67, #68, #69, #72)
  - **Poprawki bazy danych:**
    - Zmiana kolumny `id_pickup` na nullable w tabeli `orlenpaczka_package`
  - **Poprawki hooków:**
    - Odrejestrowanie starych hooków: `displayAdminOrderTop`, `displayAdminOrder`
    - Rejestracja nowego hooka: `displayAdminOrderMainBottom`
    - Zmiana nazwy klasy hooka z `DisplayAdminOrder` na `DisplayAdminOrderMainBottom`
  - **Poprawki funkcjonalności:**
    - Dodanie helpera `CarrierHelper` do sprawdzania przewoźników
    - Rozszerzenie prezentacji zamówień w panelu administracyjnym (`AdminOrderPresenter`, `OrderView`)
    - Poprawki w tworzeniu paczek (`PackageCreator`)
    - Ulepszenia w instalatorze przewoźników (`CarrierInstaller`)
  - **Poprawki UI/UX:**
    - Poprawki w szablonie widoku zamówienia (`orlen_order.html.twig`)
    - Dodanie stylów CSS dla lepszego wyświetlania
    - Poprawki w JavaScript dla formularzy i przewoźników (admin/carrier.js, admin/form.js)
  - **Tłumaczenia:**
    - Dodanie nowych tłumaczeń w plikach: ModulesOrlenpaczkaForm.pl-PL.xlf, ModulesOrlenpaczkaOrder.pl-PL.xlf, ModulesOrlenpaczkaTab.pl-PL.xlf

## 1.0.1 (2025-10-17)
  - **Nowe funkcjonalności:**
    - [DV-6979] Naprawa routingu dla PrestaShop
    - [DV-6979] Wyrzucenie niepotrzebnego installera
  - **Poprawki Bugherd:**
    - Usunięcie walidacji zamówienia kuriera przed wysyłką maili
    - Usunięcie opisu
    - Rozdzielenie danych do etykiety
    - Poprawki tłumaczeń i ustawienie domyślnego typu etykiety
    - Poprawki protokołów i logów
  - **Poprawki dla PrestaShop 8:**
    - Naprawa przełączania na PrestaShop 8
  - **Inne:**
    - Poprawki dostosowania dla PrestaShop 9
    - Różne poprawki związane z Bugherd
